@@ -5,13 +5,17 @@ namespace Doctrine\DBAL\Tests\Functional\Schema;
 use Doctrine\DBAL\Exception;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Platforms\SqlitePlatform;
+use Doctrine\DBAL\Schema\Column;
 use Doctrine\DBAL\Schema\ForeignKeyConstraint;
 use Doctrine\DBAL\Schema\Table;
+use Doctrine\DBAL\Schema\TableDiff;
 use Doctrine\DBAL\Types\BlobType;
 use Doctrine\DBAL\Types\Type;
 use Doctrine\DBAL\Types\Types;
 
+use function array_keys;
 use function array_shift;
+use function assert;
 use function dirname;
 
 class SqliteSchemaManagerTest extends SchemaManagerFunctionalTestCase
@@ -216,6 +220,28 @@ SQL;
         self::assertSame(['name'], $index->getColumns());
     }
 
+    public function testAlterTableWithSchema(): void
+    {
+        $databasePlatform = $this->connection->getDatabasePlatform();
+        assert($databasePlatform instanceof SqlitePlatform);
+        $databasePlatform->disableSchemaEmulation();
+
+        $this->dropTableIfExists('t');
+
+        $table = new Table('main.t');
+        $table->addColumn('a', Types::INTEGER);
+        $this->schemaManager->createTable($table);
+
+        self::assertSame(['a'], array_keys($this->schemaManager->listTableColumns('t')));
+
+        $tableDiff                      = new TableDiff('t');
+        $tableDiff->fromTable           = $table;
+        $tableDiff->renamedColumns['a'] = new Column('b', Type::getType(Types::INTEGER));
+        $this->schemaManager->alterTable($tableDiff);
+
+        self::assertSame(['b'], array_keys($this->schemaManager->listTableColumns('t')));
+    }
+
     public function testIntrospectMultipleAnonymousForeignKeyConstraints(): void
     {
         $this->dropTableIfExists('album');
